Clazz.declarePackage("JU");
(function(){
var c$ = Clazz.declareType(JU, "JZlib", null);
c$.version = Clazz.defineMethod(c$, "version", 
function(){
return "1.1.0";
});
})();
;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
